@@ -1,5 +1,6 @@
 from dataclasses import dataclass
 from datetime import datetime
+from typing import Optional
 
 
 @dataclass
@@ -12,3 +13,4 @@ class Lot:
     purchase_time: datetime
     investment_strategy_data: str
     profit_loss: float
+    rid: Optional[str] = None
