@@ -2,7 +2,7 @@ import os
 
 from robinhood_commons.util.io_utils import ensure_exists
 
-MAIN_EMAIL: str = 'mhowell234.daytrader@gmail.com'
+MAIN_EMAIL: str = 'mhowell234@gmail.com'
 USERS_KEY: str = 'users'
 DEFAULT_DELIMITER: str = ':'
 
@@ -16,14 +16,12 @@ RANDOM_INVESTORS: int = 7
 ERROR_SLEEP_TIME: int = 30  # in seconds
 
 
-def get_base_dir(base_dir: str = '/code/robinhood', append_user_base: bool = True) -> str:
-    if append_user_base:
-        base: str = os.path.expanduser(f'~{base_dir}')
-    else:
-        base: str = base_dir
+def get_base_dir(name: str = 'daytrader', base_dir: str = '/code/robinhood', append_user_base: bool = True) -> str:
+    base: str = os.path.expanduser(f'~{base_dir}') if append_user_base else base_dir
+    base_dir: str = f'{base}-{name}'
 
-    ensure_exists(file_path=base)
-    return base
+    ensure_exists(file_path=base_dir)
+    return base_dir
 
 
 OUTPUT_DIR: str = f'{get_base_dir()}/output'
